==> xlniuxdata-coin-1.0.2-20160516.104350-1-sources.jar: com/xunlei/niux/data/coin/vo/CoinTrans.java <==
package com.xunlei.niux.data.coin.vo;
/**
 * 欢乐券交易
 * @author Administrator
 *
 */
public class CoinTrans {
	private Long seqId;
	private String userId;
	private String userName;
	private String transDirect;
	private String transTime;
	private Integer transNum;
	private String transNo;
	private String remark;
	private String bizNo;
	private String transIp;
	private String balanceDate;
	private String actNo;
	private String gameId;
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getBalanceDate() {
		return balanceDate;
	}
	public void setBalanceDate(String balanceDate) {
		this.balanceDate = balanceDate;
	}
	public String getTransIp() {
		return transIp;
	}
	public void setTransIp(String transIp) {
		this.transIp = transIp;
	}
	public String getBizNo() {
		return bizNo;
	}
	public void setBizNo(String bizNo) {
		this.bizNo = bizNo;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getTransDirect() {
		return transDirect;
	}
	public void setTransDirect(String transDirect) {
		this.transDirect = transDirect;
	}
	public String getTransTime() {
		return transTime;
	}
	public void setTransTime(String transTime) {
		this.transTime = transTime;
	}
	public Integer getTransNum() {
		return transNum;
	}
	public void setTransNum(Integer transNum) {
		this.transNum = transNum;
	}
	public String getTransNo() {
		return transNo;
	}
	public void setTransNo(String transNo) {
		this.transNo = transNo;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	
}

==> xlniuxdata-coin-1.0.15-sources.jar: com/xunlei/niux/data/coin/vo/CoinTrans.java <==
package com.xunlei.niux.data.coin.vo;
/**
 * 欢乐券交易
 * @author Administrator
 *
 */
public class CoinTrans {
	private Long seqId;
	private String userId;
	private String userName;
	private String transDirect;
	private String transTime;
	private Integer transNum;
	private String transNo;
	private String remark;
	private String bizNo;
	private String transIp;
	private String balanceDate;
	private String actNo;
	private String gameId;

	private Integer leftNum;
	private String originTransNo;
	private String expireTime;
	private Integer transStatus;

	public Integer getTransStatus() {
		return transStatus;
	}
	public void setTransStatus(Integer transStatus) {
		this.transStatus = transStatus;
	}
	public Integer getLeftNum() {
		return leftNum;
	}
	public void setLeftNum(Integer leftNum) {
		this.leftNum = leftNum;
	}
	public String getOriginTransNo() {
		return originTransNo;
	}
	public void setOriginTransNo(String originTransNo) {
		this.originTransNo = originTransNo;
	}
	public String getExpireTime() {
		return expireTime;
	}
	public void setExpireTime(String expireTime) {
		this.expireTime = expireTime;
	}
	public String getActNo() {
		return actNo;
	}
	public void setActNo(String actNo) {
		this.actNo = actNo;
	}
	public String getGameId() {
		return gameId;
	}
	public void setGameId(String gameId) {
		this.gameId = gameId;
	}
	public String getBalanceDate() {
		return balanceDate;
	}
	public void setBalanceDate(String balanceDate) {
		this.balanceDate = balanceDate;
	}
	public String getTransIp() {
		return transIp;
	}
	public void setTransIp(String transIp) {
		this.transIp = transIp;
	}
	public String getBizNo() {
		return bizNo;
	}
	public void setBizNo(String bizNo) {
		this.bizNo = bizNo;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getUserId() {
		return userId;
	}
	public void setUserId(String userId) {
		this.userId = userId;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getTransDirect() {
		return transDirect;
	}
	public void setTransDirect(String transDirect) {
		this.transDirect = transDirect;
	}
	public String getTransTime() {
		return transTime;
	}
	public void setTransTime(String transTime) {
		this.transTime = transTime;
	}
	public Integer getTransNum() {
		return transNum;
	}
	public void setTransNum(Integer transNum) {
		this.transNum = transNum;
	}
	public String getTransNo() {
		return transNo;
	}
	public void setTransNo(String transNo) {
		this.transNo = transNo;
	}
	public String getRemark() {
		return remark;
	}
	public void setRemark(String remark) {
		this.remark = remark;
	}
	@Override
	public String toString() {
		return "CoinTrans [seqId=" + seqId + ", userId=" + userId
				+ ", userName=" + userName + ", transDirect=" + transDirect
				+ ", transTime=" + transTime + ", transNum=" + transNum
				+ ", transNo=" + transNo + ", remark=" + remark + ", bizNo="
				+ bizNo + ", transIp=" + transIp + ", balanceDate="
				+ balanceDate + ", actNo=" + actNo + ", gameId=" + gameId
				+ ", leftNum=" + leftNum + ", originTransNo=" + originTransNo
				+ ", expireTime=" + expireTime + "]";
	}
	
}
